@@ -21,6 +21,14 @@ public:
     unsigned int index);
 };
 
+class AiwaVCR3: public PIRKeysetMetaData
+{
+public:
+  AiwaVCR3(
+    QObject *guiObject,
+    unsigned int index);
+};
+
 class AiwaAudio1: public PIRKeysetMetaData
 {
 public:
@@ -45,6 +53,30 @@ public:
     unsigned int index);
 };
 
+class AiwaAudio2a: public AiwaAudio2
+{
+public:
+  AiwaAudio2a(
+    QObject *guiObject,
+    unsigned int index);
+};
+
+class AiwaAudio2b: public AiwaAudio2
+{
+public:
+  AiwaAudio2b(
+    QObject *guiObject,
+    unsigned int index);
+};
+
+class AiwaAudio2c: public AiwaAudio2
+{
+public:
+  AiwaAudio2c(
+    QObject *guiObject,
+    unsigned int index);
+};
+
 class AiwaAudio3: public PIRKeysetMetaData
 {
 public:
@@ -69,6 +101,22 @@ public:
     unsigned int index);
 };
 
+class AiwaAudio6: public PIRKeysetMetaData
+{
+public:
+  AiwaAudio6(
+    QObject *guiObject,
+    unsigned int index);
+};
+
+class AiwaCarStereo1: public PIRKeysetMetaData
+{
+public:
+  AiwaCarStereo1(
+    QObject *guiObject,
+    unsigned int index);
+};
+
 class AiwaDVD1: public PIRKeysetMetaData
 {
 public:
