@@ -14,13 +14,16 @@ enum PIRMakeName{
   Daewoo_Make,
   Denon_Make,
   DigitalStream_Make,
+  Dish_Make,
   Ei_Make,
   Elgato_Make,
   Emerson_Make,
+  Fortec_Make,
   GoldStar_Make,
   Grundig_Make,
   Hauppauge_Make,
   Hitachi_Make,
+  Homecast_Make,
   JVC_Make,
   LG_Make,
   Logitech_Make,
